@@ -1,22 +1,18 @@
     #include "person.h"                 // given earlier
 
-    // accessor functions ...()
     string const &Person::name() const
     {
         return d_name;
     }
-
     string const &Person::address() const
     {
        return d_address;
     }
-
     string const &Person::phone() const
     {
        return d_phone;
     }
-
-    size_t Person::weight() const
+    size_t Person::mass() const
     {
-       return d_weight;
+       return d_mass;
     }
